@@ -3,14 +3,15 @@
 
 from subprocess    import call
 
-from PyQt4.QtCore  import Qt, QObject, QString, QVariant, SIGNAL, SLOT
+from PyQt4.QtCore  import Qt, QObject, QSettings, QString, QVariant, \
+                          SIGNAL, SLOT
 from PyQt4.QtGui   import QAbstractItemView, QComboBox, QDialog, \
                           QDialogButtonBox, QHBoxLayout, QLabel, QLineEdit, \
                           QListWidget, QMenuBar, QMessageBox, QPushButton, \
                           QVBoxLayout, QWidget
 from ACE_file      import ACEFile;
 
-version = '0.0.4'
+version = '0.0.5'
 
 langLookup = {
     3: 'English (United Kingdom)',
@@ -39,11 +40,11 @@ class ACEAboutWindow(QDialog): #{{{1
 
         self.setWindowTitle('About')
 
-        aboutText  = '<h2>AutoComplete Editor v' + version + '</h2>'
+        aboutText  = QString('<h2>Auto-Complete Editor v%1</h2>').arg(version)
 
-        aboutText += "<p>An editor for the user's auto-complete dictionary"
-        aboutText += '<p>Written by Robin Hill <a href="mailto:maemo@robinhill.me.uk">&lt;maemo@robinhill.me.uk&gt;</a><br/>'
-        aboutText += 'Please email or post to <a href="http://talk.maemo.org/">t.m.o</a> for support</p>'
+        aboutText += "<p>An editor for the user's auto-complete dictionary</p>"
+        aboutText += QString('<p>Written by %1<br />').arg('Robin Hill <a href="mailto:maemo@robinhill.me.uk">&lt;maemo@robinhill.me.uk&gt;</a>')
+        aboutText += QString('Please email or post to %1 for support</p>').arg('<a href="http://talk.maemo.org/">t.m.o</a>')
 
         txt = QLabel()
         txt.setOpenExternalLinks(True)
@@ -72,12 +73,16 @@ class ACEMainWindow(QWidget): #{{{1
         self.setMinimumSize(800, 480)
         self.setWindowTitle('AutoComplete Editor')
 
+        self._settings = QSettings('Robin Hill', 'Auto-Complete Editor')
+
         QHBoxLayout(self)
 
-    def _getCurrentLang(self): #{{{2
-        (lang, check) = self._dictList.itemData(self._dictList.currentIndex()).toInt()
-
-        return lang
+    def _getLangName(self, langId): #{{{2
+        if langId in langLookup:
+            return QString.fromUtf8(langLookup[langId])
+        else:
+            QMessageBox.information(self, 'Unknown dictionary', QString('An unknown dictionary ID has been found.\nPlease contact\n\tRobin Hill <maemo@robinhill.me.uk>\nwith:\n\t- the ID: %1\n\t- the dictionary language you have selected (from Settings/Text input)').arg(langId))
+            return 'Unknown'
 
     def about(self): #{{{2
         aboutWin = ACEAboutWindow(self)
@@ -105,35 +110,33 @@ class ACEMainWindow(QWidget): #{{{1
             return
 
         lwrText = newText.toLower()
-        lang = self._getCurrentLang()
 
-        if lwrText in self._dicts[lang]:
+        if lwrText in self._dicts[self._curLang]:
             return
 
         self._listView.addItem(lwrText)
-        self._dicts[lang].append(lwrText)
+        self._dicts[self._curLang].append(lwrText)
 
     def clearEntries(self, checked): #{{{2
-        lang = self._getCurrentLang()
         self._listView.clear()
-        self._dicts[lang].clear()
+        self._dicts[self._curLang].clear()
 
     def deleteEntries(self, checked): #{{{2
-        lang = self._getCurrentLang()
-
         for entry in self._listView.selectedItems():
             row = self._listView.row(entry)
             self._listView.takeItem(row)
             val = entry.data(Qt.DisplayRole).toString()
 
-            self._dicts[lang].removeAt(self._dicts[lang].indexOf(val))
+            self._dicts[self._curLang].removeAt(self._dicts[self._curLang].indexOf(val))
 
     def loadDictionary(self, row): #{{{2
         self._listView.clear()
 
         if row >= 0:
             (dictId, check) = self._dictList.itemData(row).toInt()
+            self._curLang = dictId
             self._listView.addItems(self._dicts[dictId])
+            self._settings.setValue('displayDictionary', dictId)
 
     def revertChanges(self, checked): #{{{2
         self.loadData()
@@ -218,15 +221,21 @@ class ACEMainWindow(QWidget): #{{{1
         if self._dict == None:
             self._dict = ACEFile()
 
+        (curDict, check) = self._settings.value('displayDictionary').toInt()
         dictLangs = self._dict.getLanguages()
         self._dictList.clear()
         self._dicts = {}
 
         for lang in dictLangs:
             self._dicts[lang] = self._dict.getDict(lang)
-            self._dictList.addItem(QString.fromUtf8(langLookup[lang]), QVariant(lang))
+            self._dictList.addItem(self._getLangName(lang), QVariant(lang))
 
-        self._dictList.setCurrentIndex(0)
+        if curDict > 0 and curDict in dictLangs:
+            self._curLang = curDict
+            self._dictList.setCurrentIndex(dictLangs.index(curDict))
+        else:
+            self._curLang = dictLangs[0]
+            self._dictList.setCurrentIndex(0)
 
         if len(dictLangs) == 1:
             self._dictList.setEnabled(False)
